#!/bin/sh
#
# This file is intended to be executed from the q2-wrapper makefile only.
#
# Parameters:
#	$1	BINDIR		Usually /usr/local/bin
#	$2	INSTALLDIR	Usually /usr/games/quake2
#	$3	DOCDIR		Usually /usr/games/quake2/doc
#	$4	MANDIR		Usually /usr/local/man/man6
#	$5	EXECPERM	For executables and directories [755]
#	$6	READPERM	For regular files [644]
#	$7	INSTUSER	Files installed as owner $INSTUSER  root
#	$8	INSTGROUP	Files installed as group $INSTGROUP root
#

BINDIR=$1
INSTALLDIR=$2
DOCDIR=$3
MANDIR=$4
EXECPERM=$5
READPERM=$6
INSTUSER=$7
INSTGROUP=$8

# I should look in $PWD for something that looks like the quake2 tarball.
#TARBALL=$1

CDTEST="/install/data/baseq2"
CDDIR1="/mnt/cdrom"
CDDIR2="/cdrom"
TEMPDIR="/tmp/$$"
PAKFILE="pak0.pak"


#if [ `id | sed s/\(/=/ | cut -d= -f2` != 0 ] ; then
#	echo "You must run this script as root"
#	exit 1
#fi

echo ${CDDIR1}${CDTEST}    ${CDDIR2}${CDTEST}

if [ -d ${CDDIR1}${CDTEST} ] ; then
	echo "Found the Quake2 CD in ${CDDIR1}"
	REALCD=${CDDIR1}${CDTEST}

elif [ -d ${CDDIR2}${CDTEST} ] ; then
	echo "Found the Quake2 CD in ${CDDIR2}"
	REALCD=${CDDIR2}${CDTEST}
else
	echo "Can't find the Quake2 CD.  Please mount it at $CDDIR1" 
	echo "or $CDDIR2 and try again."
	exit 1
fi



if [ ! -r  ${TARBALL}  ] ; then
	echo "Can't find or read \"$TARBALL\"!"
	exit 1
fi



echo "Copying data from the Quake2 CD to $INSTALLDIR."
echo "This will take a while..."

mkdir ${INSTALLDIR}/baseq2
chown ${INSTUSER}.${INSTGROUP} ${INSTALLDIR}/baseq2
chmod $EXECPERM ${INSTUSER}.${INSTGROUP} ${INSTALLDIR}/baseq2

install -o $INSTUSER -g $INSTGROUP -m $READPERM ${REALCD}/


echo "Copying ${REALCD}/${PAKFILE} to ${INSTALLDIR}/baseq2..."
install -o $INSTUSER -g $INSTGROUP -m $READPERM  ${REALCD}/${PAKFILE} \
					${INSTALLDIR}/baseq2




# Here begins a disgusting hack intended to deal with the stupid Joliet
# filesystem.  I'll clean it up later.

echo "Copying ${REALCD/${PLAYERDIR} to ${INSTALLDIR}/baseq2/sys-players..."


mkdir ${INSTALLDIR}/baseq2/sys-players
chown ${INSTUSER}.${INSTGROUP} \
			${INSTALLDIR}/baseq2/sys-players
chmod $EXECPERM ${INSTUSER}.${INSTGROUP} \
			${INSTALLDIR}/baseq2/sys-players


mkdir ${INSTALLDIR}/baseq2/sys-players/male
chown ${INSTUSER}.${INSTGROUP} \
			${INSTALLDIR}/baseq2/sys-players/male
chmod $EXECPERM ${INSTUSER}.${INSTGROUP} \
			${INSTALLDIR}/baseq2/sys-players/male

echo "        Copying male players..."
cp ${REALCD}/baseq2/players/male/* ${INSTALLDIR}/baseq2/sys-players/male
mv ${INSTALLDIR}/baseq2/sys-players/male/claymo~1.pcx claymore_i.pcx
mv ${INSTALLDIR}/baseq2/sys-players/male/howitz~1.pcx howitzer_i.pcx
mv ${INSTALLDIR}/baseq2/sys-players/male/nighto~1.pcx nightops_i.pcx
mv ${INSTALLDIR}/baseq2/sys-players/male/pointm~1.pcx pointman_i.pcx
mv ${INSTALLDIR}/baseq2/sys-players/male/rampag~1.pcx rampage_i.pcx


mkdir ${INSTALLDIR}/baseq2/sys-players/female
chown ${INSTUSER}.${INSTGROUP} \
			${INSTALLDIR}/baseq2/sys-players/female
chmod $EXECPERM ${INSTUSER}.${INSTGROUP} \
			${INSTALLDIR}/baseq2/sys-players/female

echo "        Copying female players..."
cp ${REALCD}/baseq2/players/female/* ${INSTALLDIR}/baseq2/sys-players/female
mv ${INSTALLDIR}/baseq2/sys-players/female/briann~1.pcx brianna_i.pcx
mv ${INSTALLDIR}/baseq2/sys-players/female/jezabe~1.pcx jezabel_i.pcx
mv ${INSTALLDIR}/baseq2/sys-players/female/stiletto~1.pcx stiletto_i.pcx

echo "Copying ${REALCD/${VIDEODIR} to ${INSTALLDIR}/baseq2..."
cp -r ${REALCD/${VIDEODIR} ${INSTALLDIR}/baseq2


echo "Copying files from Quake2 CD finished..."



if [ -e $TEMPDIR ] ; then
	echo "$TEMPDIR already exists.  Moving it to ${TEMPDIR}-old."
	mv $TEMPDIR ${TEMPDIR}-old
fi

echo "Making temporary directory $TEMPDIR..."
mkdir $TEMPDIR
cp $TARBALL $TEMPDIR

pushd $PWD
cd $TEMPDIR
tar zxfv $TARBALL

# Note that the Quake2 binary is not being installed suid-root 
# as Zoid suggests.
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM   quake2       $BINDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM   ref_soft.so  $INSTALLDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM   ref_softx.so $INSTALLDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM   ref_gl.so    $INSTALLDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM   gamei386.so  $INSTALLDIR

popd
